@@ -140,7 +140,7 @@ class LDAPBackend:
         """
         return get_user_model()
 
-    def get_ldapuser(self, args, kwargs):
+    def get_ldapuser(self, *args, **kwargs):
         return _LDAPUser(*args, **kwargs)
 
     #
